@@ -2,8 +2,11 @@ from __future__ import with_statement
 
 import os
 import re
+import itertools
 import sys
 
+from boto.ec2 import connect_to_region
+from boto.ec2.autoscale import AutoScaleConnection
 from fabric.api import run, sudo
 from fabric.contrib.project import rsync_project
 
@@ -23,6 +26,37 @@ def get_hosts(args, logger=None):
     if args.exclude:
         excludes = map(lambda x: re.compile(x), args.exclude)
 
+    all_hosts = itertools.chain(
+        get_filesystem_hosts(args, dna_path),
+        get_asg_hosts(args, dna_path),
+    )
+
+    for host, data in all_hosts:
+        f = data.get('file', '')
+        if len(excludes):
+            skip = map(lambda regex: regex.search(f), excludes)
+            skip = reduce(lambda x, y: x or y, skip)
+            if skip:
+                continue
+
+        if len(includes):
+            skip = map(lambda regex: regex.search(f), includes)
+            skip = reduce(lambda x, y: x or y, skip)
+            if skip is None:
+                continue
+
+        if args.regions and data.get('region') not in args.regions:
+            continue
+        if args.providers and data.get('provider') not in args.providers:
+            continue
+        if args.services and data.get('service') not in args.services:
+            continue
+        hosts[host] = data
+
+    return hosts
+
+
+def get_filesystem_hosts(args, dna_path):
     for root, sub_folders, files in os.walk(dna_path):
         files = filter(lambda f: ".json" in f, files)
         for f in files:
@@ -31,31 +65,12 @@ def get_hosts(args, logger=None):
             provider = path.pop()
             service = path.pop()
 
-            if len(excludes):
-                skip = map(lambda regex: regex.search(f), excludes)
-                skip = reduce(lambda x, y: x or y, skip)
-                if skip:
-                    continue
-
-            if len(includes):
-                skip = map(lambda regex: regex.search(f), includes)
-                skip = reduce(lambda x, y: x or y, skip)
-                if skip is None:
-                    continue
-
-            if args.regions and region not in args.regions:
-                continue
-            if args.providers and provider not in args.providers:
-                continue
-            if args.services and service not in args.services:
-                continue
-
             host = f.replace(".json", "")
 
             if host in ["all", "default"]:
                 continue
 
-            hosts[host] = {
+            yield host, {
                 'file': f,
                 'path': os.path.join(root, f),
                 'root': root,
@@ -65,7 +80,31 @@ def get_hosts(args, logger=None):
                 'dna_path': "{0}/{1}/{2}/{3}".format(service, provider, region, f)
             }
 
-    return hosts
+
+def get_asg_hosts(args, dna_path):
+    if not args.regions:
+        return
+
+    for region in args.regions:
+        auto_scale_conn = AutoScaleConnection(args.aws_access_key_id, args.aws_secret_access_key)
+        conn = connect_to_region(
+            region,
+            aws_access_key_id=args.aws_access_key_id,
+            aws_secret_access_key=args.aws_secret_access_key,
+        )
+        for group in auto_scale_conn.get_all_groups():
+            instance_ids = [i.instance_id for i in group.instances]
+            reservations = conn.get_all_instances(instance_ids)
+            instances = [i for r in reservations for i in r.instances]
+            for instance in instances:
+                name = '{0}_{1}'.format(group.name, instance.id)
+                yield name, {
+                    'file': name,
+                    'region': region,
+                    'provider': 'AWS',
+                    'public_ip': instance.ip_address,
+                    'dna_path': os.path.join('asg', group.name),
+                }
 
 
 def rsync_project_dry(args, logger=None, **kwargs):
